/** \addtogroup gui
 * @{
 */
/** \file guiapi.h	Interface to menu module.
 * \author Lionel ULMER
 * \author Darryl Luff	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 2002 Darryl Luff
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GUIAPI_H
#define __GUIAPI_H

#include "gui_common.h"
#include "dbapi.h"

/** Add a new blank query.	*/
void gui_add_query(void);

/** Get the URL for the current connection.	*/
char *gui_get_connection_url(void);

/** Find the number of rows in the current result.	*/
int gui_get_query_count(void);

/** Find the number of columns in the current result.	*/
int gui_get_result_columns(void);

/** Lookup a field text given a column and row.	*/
char *gui_get_result_field(int row, int column);

/** Find the number of rows in the current result.	*/
int gui_get_result_rows(void);

/** Initialise the GUI.	*/
void gui_init(int argc, char **argv);

/** Check if the GUI has a valid connection.	*/
int gui_connection_ok(void);

/** Delete all open queries.	*/
void gui_delete_all_queries(void);

/** Disconnects the GUI's database connection.	*/
void gui_disconnect(void);

/** Get the current connection.	*/
DBConnection *gui_get_connection(void);

/** Load the current query from a file.	*/
void gui_load_query_from_file(char *filename);

/** Run the GUI.	*/
int gui_run(void);

/** Set the currently active connection.	*/
void gui_set_connection(DBConnection * con);

/** Send the query to the database.	*/
void gui_send_query();

/** Set the name of the current query notebook page.	*/
void gui_set_query_name(gchar *name);

/** Set the text for the currently active query.	*/
void gui_set_query_text(char *txt);

/*@}*/
#endif
